@@ -2,5 +2,5 @@
 from .tasks import *  # noqa: F401, F403
 
 
-class TypecheckerError(Exception):
+class IOCheckerError(Exception):
     pass
