@@ -20,6 +20,9 @@ class PipelineContext(ManagedClass, context_manager=PipelineContextManager):
         self.db_run = None
         self._session = None
         self.backend_name = None
+        self.map_uuid = ""
+        self.run_uuid = ""
+        self._job_ids_queue = None
 
         # store each plugin models to allow metadata clear/backup
         self._models = None
@@ -37,6 +40,15 @@ class PipelineContext(ManagedClass, context_manager=PipelineContextManager):
     def __setstate__(self, state):
         vars(self).update(state)
 
+    @property
+    def job_ids_queue(self):
+        import multiprocessing
+
+        if self._job_ids_queue is None:
+            self._job_ids_queue = multiprocessing.Queue()
+
+        return self._job_ids_queue
+
     @property
     def dry_run(self):
         args_dry_run = self.args.dry_run if self.args else False
