@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 import argparse
-import datetime
 import importlib
 import json
 import logging.config
 import os
 import pathlib
+import socket
 import sys
-import traceback
 from pathlib import Path
 from hashlib import sha256
 from uuid import uuid4
@@ -52,8 +51,8 @@ class Pipeline:
             {"help": "Display exception tracebacks."},
         ),
         "no_color": (
-            ["--no_color"],
-            {"help": "Don't colorize the command output."},
+            ["--no-color"],
+            {"help": "Don't colorize the command output.", "action": "store_true"},
         ),
         "log_level": (
             ["-ll", "--log-level"],
@@ -62,10 +61,6 @@ class Pipeline:
                 "choices": ("DEBUG", "INFO", "WARNING", "ERROR"),
             },
         ),
-        "local_mode": (
-            ["-L", "--local-mode"],
-            {"help": "Force local mode", "action": "store_true"},
-        ),
         "backend": (
             ["--backend", "-b"],
             {
@@ -172,6 +167,11 @@ class Pipeline:
                     "level"
                 ] = self.system_args.log_level
 
+            if self.system_args.no_color:
+                pipeline_config["logging"]["handlers"]["console"][
+                    "formatter"
+                ] = "simple"
+
             set_plugins_loggers_config()
 
             logging.config.dictConfig(pipeline_config["logging"])
@@ -264,6 +264,8 @@ class Pipeline:
 
     def run(self):
         """Run the pipeline"""
+
+        # remote run for slurm backend
         if context.map_uuid and context.run_uuid:
 
             run_dir = Path(f"outflow_{context.run_uuid}")
@@ -287,6 +289,7 @@ class Pipeline:
             with open(run_dir / filename, "wb") as result_file:
                 cloudpickle.dump(result, result_file)
 
+        # regular run
         else:
             if self.display_version:
                 print(f"Outflow version '{outflow_version}'")
@@ -328,6 +331,7 @@ class Pipeline:
 
             try:
                 db_run.start()
+                db_run.hostname = socket.gethostname()
 
                 with WorkflowManager() as top_level_workflow:
                     workflow = top_level_workflow.workflow
@@ -340,17 +344,8 @@ class Pipeline:
                 db_run.success()
                 return_code = 0
 
-            except Exception as e:
+            except Exception:
                 db_run.fail()
-                from outflow.management.models.runtime_exception import RuntimeException
-
-                RuntimeException.create(
-                    task=getattr(e, "db_task", None),
-                    exception_type=e.__class__.__name__,
-                    exception_msg=str(e.args),
-                    traceback="".join(traceback.format_tb(e.__traceback__)),
-                    time=datetime.datetime.now(),
-                )
 
                 # logger.print_exception() # TODO add this for file_handler but find a way to not duplicate exception in terminal
                 raise
