@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-from sqlalchemy import Column, Integer, String
-from sqlalchemy.dialects.postgresql import JSONB
+from sqlalchemy import Column, Integer, String, JSON
 from sqlalchemy.orm import relationship
 
 from outflow.core.db import Model
@@ -12,8 +11,8 @@ class Configuration(Model):
     """
 
     id = Column(Integer, primary_key=True)
-    config = Column(JSONB, nullable=False)
-    settings = Column(JSONB, nullable=False)
+    config = Column(JSON, nullable=False)
+    settings = Column(JSON, nullable=False)
     # TODO add cli args
     hash = Column(String(64), nullable=False, unique=True)
     runs = relationship("Run", back_populates="configuration")
